@@ -33,7 +33,7 @@
 
 #include "sharp/string.hpp"
 #include "debug.hpp"
-#include "ignote.hpp"
+#include "mainwindow.hpp"
 #include "noteeditor.hpp"
 #include "notemanager.hpp"
 #include "notewindow.hpp"
@@ -92,13 +92,13 @@ namespace gnote {
 
     get_window()->editor()->signal_focus_out_event().connect(
       sigc::mem_fun(*this, &NoteRenameWatcher::on_editor_focus_out));
+    get_window()->signal_backgrounded.connect(
+      sigc::mem_fun(*this, &NoteRenameWatcher::on_window_backgrounded));
 
     // FIXME: Needed because we hide on delete event, and
     // just hide on accelerator key, so we can't use delete
     // event.  This means the window will flash if closed
     // with a name clash.
-    get_window()->signal_unmap_event().connect(
-      sigc::mem_fun(*this, &NoteRenameWatcher::on_window_closed), false);
 
     // Clean up title line
     buffer->remove_all_tags (get_title_start(), get_title_end());
@@ -111,7 +111,7 @@ namespace gnote {
     // TODO: Duplicated from Update(); refactor instead
     if (m_editing_title) {
       changed ();
-      update_note_title ();
+      update_note_title(false);
       m_editing_title = false;
     }
     return false;
@@ -165,7 +165,7 @@ namespace gnote {
     else {
       if (m_editing_title) {
         changed ();
-        update_note_title ();
+        update_note_title(false);
         m_editing_title = false;
       }
     }
@@ -190,18 +190,6 @@ namespace gnote {
   }
 
 
-  bool NoteRenameWatcher::on_window_closed(GdkEventAny *)
-  {
-    if (!m_editing_title)
-      return false;
-    
-    if (!update_note_title ()) {
-      return true;
-    }
-    return false;
-  }
-
-
   std::string NoteRenameWatcher::get_unique_untitled()
   {
     int new_num = manager().get_notes().size();
@@ -217,13 +205,13 @@ namespace gnote {
   }
 
 
-  bool NoteRenameWatcher::update_note_title()
+  bool NoteRenameWatcher::update_note_title(bool only_warn)
   {
     std::string title = get_window()->get_name();
 
     Note::Ptr existing = manager().find (title);
     if (existing && (existing != get_note())) {
-      show_name_clash_error (title);
+      show_name_clash_error (title, only_warn);
       return false;
     }
 
@@ -232,7 +220,7 @@ namespace gnote {
     return true;
   }
 
-  void NoteRenameWatcher::show_name_clash_error(const std::string & title)
+  void NoteRenameWatcher::show_name_clash_error(const std::string & title, bool only_warn)
   {
     // Select text from TitleStart to TitleEnd
     get_buffer()->move_mark (get_buffer()->get_selection_bound(), get_title_start());
@@ -248,19 +236,19 @@ namespace gnote {
     /// Only pop open a warning dialog when one isn't already present
     /// Had to add this check because this method is being called twice.
     if (m_title_taken_dialog == NULL) {
+      Gtk::Window *parent = only_warn ? NULL : get_host_window();
       m_title_taken_dialog =
-        new utils::HIGMessageDialog (get_host_window(),
+        new utils::HIGMessageDialog (parent,
                                      GTK_DIALOG_DESTROY_WITH_PARENT,
                                      Gtk::MESSAGE_WARNING,
                                      Gtk::BUTTONS_OK,
                                      _("Note title taken"),
                                      message);
-      m_title_taken_dialog->set_modal(true);
       m_title_taken_dialog->signal_response().connect(
         sigc::mem_fun(*this, &NoteRenameWatcher::on_dialog_response));
+      m_title_taken_dialog->present();
+      get_window()->editor()->set_editable(false);
     }
-
-    m_title_taken_dialog->present ();
   }
 
 
@@ -268,6 +256,13 @@ namespace gnote {
   {
     delete m_title_taken_dialog;
     m_title_taken_dialog = NULL;
+    get_window()->editor()->set_editable(true);
+  }
+
+  void NoteRenameWatcher::on_window_backgrounded()
+  {
+    update_note_title(true);
+    m_editing_title = false;
   }
 
 
@@ -878,7 +873,7 @@ namespace gnote {
   }
 
 
-  bool NoteLinkWatcher::open_or_create_link(const NoteEditor & editor,
+  bool NoteLinkWatcher::open_or_create_link(const NoteEditor &,
                                             const Gtk::TextIter & start,
                                             const Gtk::TextIter & end)
   {
@@ -910,17 +905,7 @@ namespace gnote {
     // also works around the bug.
     if (link) {
       DBG_OUT ("Opening note '%s' on click...", link_name.c_str());
-      MainWindow *window = NULL;
-      if(false == Preferences::obj().get_schema_settings(Preferences::SCHEMA_GNOTE)->get_boolean(
-                    Preferences::OPEN_NOTES_IN_NEW_WINDOW)) {
-        window = MainWindow::get_owning(const_cast<NoteEditor&>(editor));
-      }
-      if(!window) {
-        window = &IGnote::obj().new_main_window();
-        window->close_on_escape(true);
-      }
-      window->present_note(link);
-      window->present();
+      MainWindow::present_default(link);
       return true;
     }
 
