@@ -73,11 +73,11 @@ namespace gnote {
     void on_delete_range(const Gtk::TextIter &,const Gtk::TextIter &);
     void update();
     void changed();
-    bool on_window_closed(GdkEventAny *);
     std::string get_unique_untitled();
-    bool update_note_title();
-    void show_name_clash_error(const std::string &);
+    bool update_note_title(bool only_warn);
+    void show_name_clash_error(const std::string &, bool);
     void on_dialog_response(int);
+    void on_window_backgrounded();
 
     bool                       m_editing_title;
     Glib::RefPtr<Gtk::TextTag> m_title_tag;
